from typing import Optional

from telebox import get_html_text, Aborting
from telebox.bot.types import Message

from {{ app_name }}.handlers.handler import AbstractHandler


class StartHandler(AbstractHandler):

    def process_event(self, event: Message) -> Optional[Aborting]:
        self.env.context_bot.send_message(
            get_html_text(
                "👋 Hello, <b>{name}</b>!",
                name=event.from_.full_name
            )
        )
